==> haskell-transformers-compat-0.6.5-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-compat
version:              0.6.5
visibility:           public
id:                   transformers-compat-0.6.5-5FpQwDSHwAD8xLwpEoaQi
key:                  transformers-compat-0.6.5-5FpQwDSHwAD8xLwpEoaQi
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/transformers-compat/
synopsis:             A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.

    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.

    Note: missing methods are not supplied, but this at least permits the types to be used.

category:             Compatibility
abi:                  6451152a0fad4767740fd150e9ffd45b
exposed:              True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal

hidden-modules:       Paths_transformers_compat
import-dirs:          /usr/lib/ghc-8.10.1/site-local/transformers-compat-0.6.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/transformers-compat-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/transformers-compat-0.6.5

hs-libraries:         HStransformers-compat-0.6.5-5FpQwDSHwAD8xLwpEoaQi
depends:              base-4.14.0.0 ghc-prim-0.6.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock

haddock-html:         /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-compat-0.6.5-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-compat
version:              0.6.5
visibility:           public
id:                   transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc
key:                  transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/transformers-compat/
synopsis:             A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.

    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.

    Note: missing methods are not supplied, but this at least permits the types to be used.

category:             Compatibility
abi:                  30f00c8fc27dff27c77f6f5f3328e820
exposed:              True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal

hidden-modules:       Paths_transformers_compat
import-dirs:          /usr/lib/ghc-8.10.2/site-local/transformers-compat-0.6.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/transformers-compat-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/transformers-compat-0.6.5

hs-libraries:         HStransformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc
depends:              base-4.14.1.0 ghc-prim-0.6.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock

haddock-html:         /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
